diff src/org/tmatesoft/hg/internal/RevisionSet.java @ 651:6e98d34eaca8

Push: tests (push to empty, push changes, respect secret)
author Artem Tikhomirov <tikhomirov.artem@gmail.com>
date Mon, 01 Jul 2013 21:19:53 +0200
parents 3b275cc2d2aa
children cd77bf51b562
line wrap: on
line diff
--- a/src/org/tmatesoft/hg/internal/RevisionSet.java	Fri Jun 28 19:27:26 2013 +0200
+++ b/src/org/tmatesoft/hg/internal/RevisionSet.java	Mon Jul 01 21:19:53 2013 +0200
@@ -92,7 +92,8 @@
 	}
 
 	/**
 	 * Any ancestor of an element from the supplied children set found in this one.
 	 */
 	public RevisionSet ancestors(RevisionSet children, HgParentChildMap<HgChangelog> parentHelper) {
 		if (isEmpty()) {
@@ -190,6 +191,9 @@
 		return elements.isEmpty();
 	}
 
+	public int size() {
+		return elements.size();
+	}
 
 	public List<Nodeid> asList() {
 		return new ArrayList<Nodeid>(elements);
@@ -92,7 +92,8 @@
 
 	/**
-	 * Any ancestor of an element from the supplied children set found in this one.
+	 * Any ancestor of an element from the supplied child set found in this one. 
+	 * Elements of the supplied child set are not part of return value.  
 	 */
 	public RevisionSet ancestors(RevisionSet children, HgParentChildMap<HgChangelog> parentHelper) {